@@ -1,6 +1,6 @@
 package CPAN::Perl::Releases;
 {
-  $CPAN::Perl::Releases::VERSION = '1.28';
+  $CPAN::Perl::Releases::VERSION = '1.30';
 }
 
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
@@ -399,6 +399,10 @@ our $data =
     "tar.bz2" => "R/RJ/RJBS/perl-5.18.1-RC1.tar.bz2",
     "tar.gz" => "R/RJ/RJBS/perl-5.18.1-RC1.tar.gz",
   },
+  "5.18.1-RC2" => {
+    "tar.bz2" => "R/RJ/RJBS/perl-5.18.1-RC2.tar.bz2",
+    "tar.gz" => "R/RJ/RJBS/perl-5.18.1-RC2.tar.gz",
+  },
   "5.19.0" => {
     "tar.bz2" => "R/RJ/RJBS/perl-5.19.0.tar.bz2",
     "tar.gz" => "R/RJ/RJBS/perl-5.19.0.tar.gz",
@@ -523,7 +527,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 1.28
+version 1.30
 
 =head1 SYNOPSIS
 
